# DIS_TP
This is the python version of the code I used for my master's thesis. It computes the F2 and FL structure functions for DIS with heavy-quark production at NLO, NNLO and N3LO. It is also able to construct the scale varied result (at the moment only threshold scale variation
is available) and obtain uncertainty bands based on that and on coefficient function uncertainties (at N3LO).
